require 'nehm/tracks_view_command'

module Nehm

  class SearchCommand < TracksViewCommand

    def initialize
      super

      add_option(:"-t", '-t PATH',
                 'Download track(s) to PATH')

      add_option(:"-pl", '-pl PLAYLIST',
                 'Add track(s) to iTunes playlist with PLAYLIST name')

      add_option(:"-lim", '-lim NUMBER',
                 'Show NUMBER tracks on each page')

      add_option(:"-dl", '-dl yes',
                 "Don't add tracks to iTunes. Just download and set tags")

    end

    def execute
      # Convert dash-options to normal options
      options_to_convert = { :"-t"   => :to,
                             :"-pl"  => :pl,
                             :"-lim" => :limit,
                             :"-dl"  => :dl }

      options_to_convert.each do |k, v|
        value = @options[k]
        @options.delete(k)
        @options[v] = value unless value.nil?
      end

      @query = @options[:args].join(' ')
      super
    end

    def arguments
      { 'QUERY' => 'Search query' }
    end

    def program_name
      'nehm search'
    end

    def summary
      'Search tracks, print them nicely and download, set tags and add ' \
                                                          'to iTunes selected'
    end

    def usage
      "#{program_name} QUERY [OPTIONS]"
    end

    protected

    def get_tracks
      UI.term 'You must provide a query' if @query.empty?

      @track_manager.search(@query, @limit, @offset)
    end

  end
end
