require 'nehm/artwork'

module Nehm

  # Primitive for SoundCloud track

  class Track

    attr_reader :hash

    def initialize(hash)
      @hash = hash
    end

    def artist
      name[0]
    end

    def artwork
      Artwork.new(self)
    end

    def duration
      seconds = @hash['duration'] / 1000

      time = Time.at(seconds)
      time -= time.utc_offset

      time.hour > 0 ? time.strftime('%H:%M:%S') : time.strftime('%M:%S')
    end

    def file_name
      "#{full_name.tr(",./'\\\"$%", '')}.mp3"
    end

    def file_path
      File.join(ENV['dl_path'], file_name)
    end

    def full_name
      "#{artist} - #{title}"
    end

    def id
      @hash['id']
    end

    # Returns artist and title in array
    def name
      title = @hash['title']

      separators = [' - ', ' ~ ']
      separators.each do |sep|
        return title.split(sep, 2) if title.include? sep
      end

      [@hash['user']['username'], title]
    end

    def title
      name[1]
    end

    def url
      # API V2 track hash has no 'stream_url' but 'uri'
      dl_url = @hash['uri'] ? "#{@hash['uri']}/stream" : @hash['stream_url']
      "#{dl_url}?client_id=#{HTTPClient::CLIENT_ID}"
    end

    def year
      @hash['created_at'][0..3].to_i
    end

  end
end
